# mautrix-instagram
![Languages](https://img.shields.io/github/languages/top/mautrix/instagram.svg)
[![License](https://img.shields.io/github/license/mautrix/instagram.svg)](LICENSE)
[![Release](https://img.shields.io/github/release/mautrix/instagram/all.svg)](https://github.com/mautrix/instagram/releases)
[![GitLab CI](https://mau.dev/mautrix/instagram/badges/master/pipeline.svg)](https://mau.dev/mautrix/instagram/container_registry)
[![Code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)

A Matrix-Instagram DM puppeting bridge.

### Documentation
All setup and usage instructions are located on
[docs.mau.fi](https://docs.mau.fi/bridges/python/instagram/index.html).
Some quick links:

* [Bridge setup](https://docs.mau.fi/bridges/python/setup.html?bridge=instagram)
  (or [with Docker](https://docs.mau.fi/bridges/general/docker-setup.html?bridge=instagram))
* Basic usage: [Authentication](https://docs.mau.fi/bridges/python/instagram/authentication.html)

### Features & Roadmap
[ROADMAP.md](https://github.com/mautrix/instagram/blob/master/ROADMAP.md)
contains a general overview of what is supported by the bridge.

## Discussion
Matrix room: [`#instagram:maunium.net`](https://matrix.to/#/#instagram:maunium.net)
